Cross-platform remote administration agent for 1C:Enterprise
=============
|Build Status Travis| |Build Status AppVeyor| |Coverage Status| |PYPI| |License: GPL v3|


.. |Build Status Travis| image:: https://travis-ci.org/vbondarevsky/hydra_agent.svg?branch=develop
   :target: https://travis-ci.org/vbondarevsky/hydra_agent
.. |Build Status AppVeyor| image:: https://ci.appveyor.com/api/projects/status/lsq6bvl80205t060?svg=true
   :target: https://ci.appveyor.com/project/vbondarevsky/hydra-agent
.. |Coverage Status| image:: https://codecov.io/gh/vbondarevsky/hydra_agent/branch/develop/graph/badge.svg
   :target: https://codecov.io/gh/vbondarevsky/hydra_agent
.. |License: GPL v3| image:: https://img.shields.io/badge/License-GPL%20v3-blue.svg
   :target: https://www.gnu.org/licenses/gpl-3.0
.. |PYPI| image:: https://badge.fury.io/py/hydra-agent.svg
   :target: https://badge.fury.io/py/hydra-agent
